/*                                                                            *
 *                                                                            *
 *                  Copyright 1987, 1988, 1989 Netwise, Inc.                  *
 *                              All Rights Reserved                           *
 *   This software contains information which is proprietary to and a trade   *
 *   secret of Netwise, Inc. It is not to be used, reproduced, or disclosed   *
 *   except as authorized in your license agreement.                          *
 *                                                                            *
 *                          Restricted Rights Legend                          *
 *   Use, duplication,  or  disclosure  by the  Government  is  subject  to   *
 *   restrictions as set forth in subparagraph (c)(1)(ii) of the Rights  in   *
 *   Technical Data and  Computer Software clause  at 252.227-7013, or  the   *
 *   equivalent Government clause for other agencies.                         *
 *   Contractor: Netwise, Inc., Boulder, CO 80301 USA                         *
 *                                                                            *
 */ 
/*
 * File: authen\client\client.c
 *
 * This example works in the following environments:
 *	NetWare RPC 1.0, NetWare 2.1 or higher, DOS 3.3
 *
 * This is the driver program for the authen example. It calls the
 * add and sub routines using a client "key". This key is used to
 * determine whether the server will handle the request (i.e. the
 * key matches the server's key) or reject it. Refer to the authen_i.rpc
 * file to see the custom code for handling this authentication
 * process.
 */ 

#include <stdio.h>
#include "authen.h"	/* client header file, created by the RPC compiler */

extern int _rpcerr_;	/* declare RPC error code */

/* Server_Name is used to set the process-binding variable.
 * It must be defined as the name the server registers under.
 */
#define Server_Name  "example"

/* declare variable of type server_name for process binding */
server_name sname;

int client_key = 0x1234;		/* authentication key */

main()
{
	int	arg1, arg2;
	int	result;

	sname = Server_Name;

	/*
	 * example of call to add
	 */
	arg1 = 1234;
	arg2 = 5678;

	printf("CLIENT: calling add() with %d and %d\n", arg1, arg2);
	result = add(arg1, arg2);

	if (_rpcerr_) {		/* check RPC error code */
		if (_rpcerr_ == INVALID_KEY_ERROR) {
			printf("CLIENT: invalid key sent to server\n");
		} else {
			printf("CLIENT: RPC error %d in add()\n", _rpcerr_);
		}
		exit(1);
	}
	printf("CLIENT: add() returned %d\n\n", result);

	/*
	 * example of call to sub
	 */
	arg1 = result;
	arg2 = 5678;

	printf("CLIENT: calling sub() with %d and %d\n", arg1, arg2);
	result = sub(arg1, arg2);

	if (_rpcerr_) {		/* check RPC error code */
		if (_rpcerr_ == INVALID_KEY_ERROR) {
			printf("CLIENT: invalid key sent to server\n");
		} else {
			printf("CLIENT: RPC error %d in sub()\n", _rpcerr_);
		}
		exit(1);
	}
	printf("CLIENT: sub() returned %d\n\n", result);

	/*
	 * example of second call to add, with invalid key code 
	 */

	client_key = 0x4321;
	arg1 = 1234;
	arg2 = 5678;

	printf("CLIENT: calling add() with %d and %d\n", arg1, arg2);
	result = add(arg1, arg2);

	if (_rpcerr_) {		/* check RPC error code */
		if (_rpcerr_ == INVALID_KEY_ERROR) {
			printf("CLIENT: invalid key sent to server\n");
		} else {
			printf("CLIENT: RPC error %d in add()\n", _rpcerr_);
		}
		exit(1);
	}
	printf("CLIENT: add() returned %d\n\n", result);

	exit(0);
}
