/*                                                                            *
 *                                                                            *
 *                  Copyright 1987, 1988, 1989 Netwise, Inc.                  *
 *                              All Rights Reserved                           *
 *   This software contains information which is proprietary to and a trade   *
 *   secret of Netwise, Inc. It is not to be used, reproduced, or disclosed   *
 *   except as authorized in your license agreement.                          *
 *                                                                            *
 *                          Restricted Rights Legend                          *
 *   Use, duplication,  or  disclosure  by the  Government  is  subject  to   *
 *   restrictions as set forth in subparagraph (c)(1)(ii) of the Rights  in   *
 *   Technical Data and  Computer Software clause  at 252.227-7013, or  the   *
 *   equivalent Government clause for other agencies.                         *
 *   Contractor: Netwise, Inc., Boulder, CO 80301 USA                         *
 *                                                                            *
 */ 
/*
 * File: freemem\client\client.c
 *
 * This example works in the following environments:
 *	NetWare RPC 1.0, NetWare 2.1 or higher, DOS 3.3
 *
 * This is the driver program for the freemem example. This example 
 * demonstrates dynamic allocation of memory by the client RPC
 * code and the remote procedure.
 */

#include <stdio.h>
#include "freemem.h"	/* client header file, created by the RPC compiler */

extern int _rpcerr_;	/* declare RPC error code */

/* Server_Name is used to set the process-binding variable.
 * It must be defined as the name the server registers under.
 */
#define Server_Name  "example"

/* declare variable of type server_name for process binding */
server_name sname;

char *string;

main()
{
	int result;

	sname = Server_Name;
	
	string = (char *)0;

	/* example of call to remote procedure get_string() */
	printf("CLIENT: calling get_string(15)\n");
	result = get_string(15);

	if (_rpcerr_) {		/* check RPC return code */
		printf("CLIENT: RPC error %d in get_string() call\n",
			_rpcerr_);
		exit(1);
	}

	printf("CLIENT: get_string(%d) returned '%s'\n", 15, string);

	/* Memory for 'string' was dynamically allocated by the client
	   stub code.  Therefore, the client application must call
	   free() to de-allocate this memory when it is no longer needed. */

	free(string);

	/* another example of call to remote procedure get_string() */
	printf("CLIENT: calling get_string(123)\n");
	result = get_string(123);

	if (_rpcerr_) {		/* check RPC return code */
		printf("CLIENT: RPC error %d in get_string() call\n",
			_rpcerr_);
		exit(1);
	}

	printf("CLIENT: get_string(%d) returned '%s'\n", 123, string);

	/* Memory for 'string' was dynamically allocated by the client
	   stub code.  Therefore, the client application must call
	   free() to de-allocate this memory when it is no longer needed. */

	free(string);
	
	exit(0);
}
