/*                                                                            *
 *                                                                            *
 *                  Copyright 1987, 1988, 1989 Netwise, Inc.                  *
 *                              All Rights Reserved                           *
 *   This software contains information which is proprietary to and a trade   *
 *   secret of Netwise, Inc. It is not to be used, reproduced, or disclosed   *
 *   except as authorized in your license agreement.                          *
 *                                                                            *
 *                          Restricted Rights Legend                          *
 *   Use, duplication,  or  disclosure  by the  Government  is  subject  to   *
 *   restrictions as set forth in subparagraph (c)(1)(ii) of the Rights  in   *
 *   Technical Data and  Computer Software clause  at 252.227-7013, or  the   *
 *   equivalent Government clause for other agencies.                         *
 *   Contractor: Netwise, Inc., Boulder, CO 80301 USA                         *
 *                                                                            *
 */ 
/*
 * File: lostptr\client\client.c
 *
 * This example works in the following environments:
 *	NetWare RPC 1.0, NetWare 2.1 or higher, DOS 3.3
 *
 * This is the driver program for the lostptr example. The _lostptr_
 * routine is defined in this file as well as the routine add_record().
 */

#include <stdio.h>
#include "lostptr.h"	/* client header file, created by RPC compiler */

extern int _rpcerr_;	/* declare RPC error code */

/* Server_Name is used to set the process-binding variable.
 * It must be defined as the name the server registers under.
 */
#define Server_Name  "example"

/* declare variable of type server_name for process binding */
server_name sname;

struct customer *cust_list;	/* pointer to head of linked list */

main()
{
	struct customer *lp;
	int result;

	sname = Server_Name;

	add_record("Ralph Cramden", "Brooklyn, NY", "555-3333");
	add_record("Andy Taylor  ", "Mayberry, NC", "555-6789");
	add_record("Fred Flintstone", "Bedrock", "555-2222");

	printf("CLIENT: Before call to fix_list()  Customer List:\n");
	for (lp = cust_list; lp != NULL; lp = lp->c_next) {
		printf("         %s  %s  %s\n", lp->c_name, 
			lp->c_addr, lp->c_phone);
	}

	result = fix_list(&cust_list);  /* Make the remote procedure call */

	if (_rpcerr_) {		/* check RPC return code */
		printf("CLIENT: RPC error %d in fix_list() call\n",
			_rpcerr_);
		exit(1);
	}

	printf("CLIENT: After call to fix_list()  Customer List:\n");
	for (lp = cust_list; lp != NULL; lp = lp->c_next) {
		printf("         %s  %s  %s\n", lp->c_name, 
			lp->c_addr, lp->c_phone);
	}

	printf("CLIENT: second call to remote procedure fix_list()\n");
	result = fix_list(&cust_list);  /* Make the remote procedure call */

	if (_rpcerr_) {		/* check RPC return code */
		printf("CLIENT: RPC error %d in fix_list() call\n",
			_rpcerr_);
		exit(1);
	}

	printf("CLIENT: After call to fix_list()  Customer List:\n");
	for (lp = cust_list; lp != NULL; lp = lp->c_next) {
		printf("         %s  %s  %s\n", lp->c_name, 
			lp->c_addr, lp->c_phone);
	}

	printf("CLIENT: third call to remote procedure fix_list()\n");
	result = fix_list(&cust_list);  /* Make the remote procedure call */

	if (_rpcerr_) {		/* check RPC return code */
		printf("CLIENT: RPC error %d in fix_list() call\n",
			_rpcerr_);
		exit(1);
	}

	printf("CLIENT: After call to fix_list()  Customer List:\n");
	for (lp = cust_list; lp != NULL; lp = lp->c_next) {
		printf("         %s  %s  %s\n", lp->c_name, 
			lp->c_addr, lp->c_phone);
	}

	exit(0);
}

_lostptr_(ptr, desc)
char *ptr;
char *desc;
{
	printf("CLIENT: lostptr called for a pointer to struct %s\n", desc);
	printf("CLIENT: customer name in lost structure = %s\n",
					((struct customer *)ptr)->c_name);
	free(ptr);
}

add_record(name, addr, phone)
char *name;
char *addr;
char *phone;
{
	/* add a new customer to the customer linked list */
	extern char *malloc();
	struct customer *lp, *mp;

	if (cust_list != NULL) {
		/* find end of list */
		for (lp = cust_list; lp->c_next != NULL; lp = lp->c_next) 
			;
	}

	if ((mp=(struct customer *)malloc(sizeof(struct customer))) ==
		(struct customer *)NULL) {
		printf ("CLIENT: malloc failed!  execution aborted\n");
		exit (1);
		}

	strcpy(mp->c_name, name);
	strcpy(mp->c_addr, addr);
	strcpy(mp->c_phone, phone);
	mp->c_next = NULL;
	if (cust_list == NULL) {
		cust_list = mp;
	} else {
		lp->c_next = mp;
	}
}
