/*                                                                            *
 *                                                                            *
 *                  Copyright 1987, 1988, 1989 Netwise, Inc.                  *
 *                              All Rights Reserved                           *
 *   This software contains information which is proprietary to and a trade   *
 *   secret of Netwise, Inc. It is not to be used, reproduced, or disclosed   *
 *   except as authorized in your license agreement.                          *
 *                                                                            *
 *                          Restricted Rights Legend                          *
 *   Use, duplication,  or  disclosure  by the  Government  is  subject  to   *
 *   restrictions as set forth in subparagraph (c)(1)(ii) of the Rights  in   *
 *   Technical Data and  Computer Software clause  at 252.227-7013, or  the   *
 *   equivalent Government clause for other agencies.                         *
 *   Contractor: Netwise, Inc., Boulder, CO 80301 USA                         *
 *                                                                            *
 */ 
/*                                                                            *
 * File: ovrwrite\client\client.c
 *
 * This example runs in the following environments:
 *	NetWare RPC 1.0, NetWare 2.1 or higher, DOS 3.3
 *
 * Client code for the ovrwrite example.  An array of pointers to
 * character strings is passed to, and returned from, a remote procedure.
 * The _overwrite_ procedure is automatically called from the client
 * stub when the strings are returned, as they are placed in memory
 * allocated by the stub, and the pointers are changed (overwritten)
 * to point to the returned strings.
 *
 */

#include <stdio.h>
#include "ovrwrite.h"	/* client header file, created by RPC compiler */

extern int _rpcerr_;	/* declare RPC error code */

/* Server_Name is used to set the process-binding variable.
 * It must be defined as the name the server registers under.
 */
#define Server_Name  "example"

/* declare variable of type server_name for process binding */
server_name sname;

main()
{
	char *strs[MAXSTRS];
	int num;
	int i, result;
	extern char *malloc();

	sname = Server_Name;

	/* Example of call to update() */

	num = MAXSTRS;
	for (i=0; i<num; i++) {
		if ((strs[i] = malloc(15)) == NULL) {
			printf ("CLIENT: malloc failed!  execution aborted\n");
			exit (1);
			}
		sprintf(strs[i], "client: %d", i);
	}

	printf("CLIENT: update called \n");
	result = update(strs, &num);

	if (_rpcerr_) {		/* check RPC return code */
		printf("CLIENT: RPC error %d in update() call\n", _rpcerr_);
		exit(1);
	}

	for (i=0; i<num; i++) {
		printf("strs[%d] = %s\n", i, strs[i]);
	}

	/* Example of another call to update() */

	num = MAXSTRS/2;
	for (i=0; i<num; i++) {
		if ((strs[i] = malloc(15)) == NULL) {
			printf ("CLIENT: malloc failed!  execution aborted\n");
			exit (1);
			}
		sprintf(strs[i], "client: %d", i+100);
	}

	printf("CLIENT: update called again\n");
	result = update(strs, &num);

	if (_rpcerr_) {		/* check RPC return code */
		printf("CLIENT: RPC error %d in update() call\n", _rpcerr_);
		exit(1);
	}

	for (i=0; i<num; i++) {
		printf("strs[%d] = %s\n", i, strs[i]);
	}

	exit(0);
}

_overwrite_(ptr, desc)
char *ptr;
char *desc;
{
	printf("CLIENT: overwrite called before overwriting type %s\n", desc);
	printf("CLIENT: overwrite data = %s\n", ptr);
	free(ptr);
}
