/*                                                                            *
 *                                                                            *
 *                  Copyright 1987, 1988, 1989 Netwise, Inc.                  *
 *                              All Rights Reserved                           *
 *   This software contains information which is proprietary to and a trade   *
 *   secret of Netwise, Inc. It is not to be used, reproduced, or disclosed   *
 *   except as authorized in your license agreement.                          *
 *                                                                            *
 *                          Restricted Rights Legend                          *
 *   Use, duplication,  or  disclosure  by the  Government  is  subject  to   *
 *   restrictions as set forth in subparagraph (c)(1)(ii) of the Rights  in   *
 *   Technical Data and  Computer Software clause  at 252.227-7013, or  the   *
 *   equivalent Government clause for other agencies.                         *
 *   Contractor: Netwise, Inc., Boulder, CO 80301 USA                         *
 *                                                                            *
 */ 
/*
 * File: tags\client\client.c
 *
 * This example runs in the following environments:
 *	NetWare RPC 1.0, NetWare 2.1 or higher, DOS 3.3
 *
 * Client code for the tags example.  This program calls one
 * remote procedure, opening and closing the connection for
 * the call using the non-persistent style of process binding.
 */ 

#include <stdio.h>
#include "tags.h"	/* client header file, created by the RPC compiler */

extern int _rpcerr_;	/* declare RPC error code */

/* Server_Name is used to set the process-binding variable.
 * It must be defined as the name the server registers under.
 */
#define Server_Name  "example"

/* declare variable of type server_name for process binding */
server_name sname;

main()
{
	char *ip;	/* Pointer to buffer for image returned by get_image */
	int length;	/* Length  of image buffer returned by get_image */
	int i;
	int result;

	sname = Server_Name;

	/* Example of call to get_image() */
	printf("CLIENT: calling get_image()\n");
	result = get_image(&length, &ip);

	/* check RPC error call after remote call */
	if (_rpcerr_) {
		printf("CLIENT: RPC error %d in get_image() call\n", _rpcerr_);
		exit(1);
	}

	if (result == 0) {
		printf("CLIENT: get_image() returned %d bytes\n", length);
		printf("CLIENT: First bytes of the image:\n");
		for (i = 0; i < ((length > 10) ? 10 : length); i++) {
			printf("  %x", (*ip++ & 0xff));
		}
		printf("\n");
	} else {
		printf("CLIENT: get_image() error (%d)\n", result);
	}

	exit(0);
}
