/*                                                                            *
 *                                                                            *
 *                  Copyright 1987, 1988, 1989 Netwise, Inc.                  *
 *                              All Rights Reserved                           *
 *   This software contains information which is proprietary to and a trade   *
 *   secret of Netwise, Inc. It is not to be used, reproduced, or disclosed   *
 *   except as authorized in your license agreement.                          *
 *                                                                            *
 *                          Restricted Rights Legend                          *
 *   Use, duplication,  or  disclosure  by the  Government  is  subject  to   *
 *   restrictions as set forth in subparagraph (c)(1)(ii) of the Rights  in   *
 *   Technical Data and  Computer Software clause  at 252.227-7013, or  the   *
 *   equivalent Government clause for other agencies.                         *
 *   Contractor: Netwise, Inc., Boulder, CO 80301 USA                         *
 *                                                                            *
 */ 
/*
 * File: tutorial\stdalone\stdalone.c
 *
 * This example runs in the following environments:
 *	NetWare RPC 1.0, NetWare 2.1 or higher, DOS 3.3
 *
 * Stand-alone code for the tutorial example.
 *
 */ 

#include <stdio.h>

#define TRUE      1
#define FALSE     0
#define SUCCESS   0
#define ERROR    -1 
#define PERMANENT '0'
#define TEMPORARY '1'
#define OLDNAME   1
#define OLDNUM    2
#define DBFULL    3
#define MAXREC   50
#define FIRSTNAME 30
#define LASTNAME 30
#define NAMESIZE (FIRSTNAME + LASTNAME)
#define AGCYSIZE 60

int recerr;

struct employee_record {
	char employee_name[NAMESIZE];
	char employee_type;
	union {
		int employee_id;
		char temp_agency[AGCYSIZE];
	} employee_info;
} ;

static struct employee_record database_record[MAXREC+1];

void init();
void add_employee_info();
void list_employee_info();
int append_record();
int get_record();
	
main() 
{
	char chr;

	/* call initialization procedure */
	init();

	/* prompt user for function */
	while (TRUE) {
		printf("\nType 'a' to append a new employee record\n");
		printf("     'l' to list an employee record\n");
		printf("     'x' to exit from this program\n");
		scanf(" %c", &chr);

		switch (chr) {
		case 'a':
			add_employee_info();
			break;
		case 'l':
			list_employee_info();
			break;
		case 'x':
			exit(0);
		default:
			printf("Enter only 'a', 'l', or 'x'\n");
			break;
		}
	}	
}

void
list_employee_info()
{
/* prompt for an employee name, call get_record
 * to get the employee information from the database, and then
 * display it
 */
	int status;
	char name1[FIRSTNAME], name2[LASTNAME];
	struct employee_record *record_ptr;
	char name[NAMESIZE];

	printf("\nEnter employee name, first name then last name: ");
	scanf("%s %s", name1, name2);
	strcpy(name, name1);
	strcat(name, " ");
	strcat(name, name2);

	/* get employee info from database */
	status = get_record(name, &record_ptr);
	if (status) {
		printf("Employee %s not found\n", name);
		return;
	}

	/* display employee info based on employee type */
	switch (record_ptr->employee_type) {
	case PERMANENT:
		printf("Employee %s, Permanent, No. %d\n",
				record_ptr->employee_name,
				record_ptr->employee_info.employee_id);
		break;
	case TEMPORARY:
		printf("Employee %s, Temporary, Agency %s\n",
				record_ptr->employee_name,
				record_ptr->employee_info.temp_agency);
		break;
	default:
		printf("Employee %s, Invalid employee_type\n",
				record_ptr->employee_name);
		break;
	}
	return;
}

	
void
add_employee_info()
{
/* prompt for employee information and then add
 * the employee to the database.
 */
	int loop, status;
	char name1[FIRSTNAME], name2[LASTNAME];
	struct employee_record record;

	loop = TRUE;
	printf("\nEnter employee name, first name then last name: ");
	scanf("%s %s", name1, name2);
	strcpy(record.employee_name, name1);
	strcat(record.employee_name, " ");
	strcat(record.employee_name, name2);
	printf("Enter employee type, %c=permanent, %c=temporary: ",
		PERMANENT, TEMPORARY);
	scanf(" %c", &record.employee_type);

	/* get additional employee info depending on employee type */
	while (loop) { 
		switch (record.employee_type) {
		case PERMANENT:
			printf("Enter employee number: ");
			scanf("%d", &record.employee_info.employee_id);
			loop = FALSE;
			break;
		case TEMPORARY:
			printf("Enter agency name: ");
			scanf("%s", record.employee_info.temp_agency);
			loop = FALSE;
			break;
		default:
			printf("Enter %c=permanent, %c=temporary\n",
						PERMANENT, TEMPORARY);
			scanf(" %c", &record.employee_type);	
			break;
		}
	}

	/* add record to database and check for errors */
	status = append_record(&record);
	if (status) {
		printf("Error appending new employee record\n");
		switch (recerr) {
		case OLDNAME:
			printf("Duplicate employee name\n");
			break;
		case OLDNUM:
			printf("Duplicate employee number\n");
			break;
		case DBFULL:
			printf("Data base is full\n");
			break;
		default:
			printf("Unrecognized error\n");
		}			
	}
	return;
}

void
init()
{
/* database initialization procedure */

	database_record[0].employee_name[0] = '\0';
}

int
get_record (name, record_ptr)
char name[NAMESIZE];			/* employee name */
struct employee_record **record_ptr;	/* upon return, set to ptr
					 * to employee record */
{
/* retrieve an employee record from the database */

	struct employee_record *ptr;

	ptr = database_record;
	while (ptr->employee_name[0] != '\0') {
		if (strcmp(ptr->employee_name, name))
			ptr++;
		else {
			*record_ptr = ptr;
			return (SUCCESS);
		}	
	}
	return (ERROR);
}

int
append_record (record_ptr)
struct employee_record *record_ptr;	/* ptr to record to add */
{
/* add an employee record to the database */

	struct employee_record *ptr;

	/* look through database for duplicate employee names
	 * or numbers, and find room for a new record
	 */
	ptr = database_record;
	while (ptr->employee_name[0] != '\0') {
		if (strcmp(ptr->employee_name,
				record_ptr->employee_name) == 0) {
			recerr = OLDNAME;
			return (ERROR);
		}
		if (record_ptr->employee_type == PERMANENT) { 
			if (ptr->employee_info.employee_id == 
			    record_ptr->employee_info.employee_id) {
			recerr = OLDNUM;
			return (ERROR);
			}
		}
		if (++ptr > &database_record[MAXREC]) {
			recerr = DBFULL;
			return (ERROR);
		}
	}

	/* add employee record to database */
	*ptr = *record_ptr;
	(++ptr)->employee_name[0] = '\0';
	return (SUCCESS);
}
